"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateEmailFormat = exports.convertToDateString = exports.convertToMoneyString = void 0;
/**
 * @description  Takes a number and returns it as currency format
 * @param {number} amount
 * @param {string} countryCode
 * @param {string} style
 * @param {string} currencyCode
 * @return {string} formatted string
 */
function convertToMoneyString({ amount, countryCode, style, currencyCode }) {
    return new Intl.NumberFormat(countryCode, {
        style: style,
        currency: currencyCode
    }).format(amount);
}
exports.convertToMoneyString = convertToMoneyString;
/**
 * @description  Takes a date-like string and returns a formatted date with the specified country code
 * @param {string} date
 * @param {string} countryCode
 * @returns {string} formatted date string
 */
function convertToDateString({ date, countryCode }) {
    const newDate = new Date(date);
    newDate.setMinutes(newDate.getMinutes() + newDate.getTimezoneOffset());
    return new Intl.DateTimeFormat(countryCode).format(newDate);
}
exports.convertToDateString = convertToDateString;
/**
 * @description   Takes an string and verifies if has a correct email format
 * @param {string} email
 * @returns {boolean} true or false
 */
function validateEmailFormat({ email }) {
    if (/^\w+([\.-]?\w+)*@\w+([\.-]?\w+)*(\.\w{2,3})+$/.test(email)) {
        return true;
    }
    return false;
}
exports.validateEmailFormat = validateEmailFormat;
